@@ -108,11 +108,17 @@ class Connector:
         # Use the InstanceConnectionManager to establish an SSL Connection.
         #
         # Return a DBAPI connection
-
+        enable_iam_auth = kwargs.pop("enable_iam_auth", self._enable_iam_auth)
         if instance_connection_string in self._instances:
             icm = self._instances[instance_connection_string]
+            if enable_iam_auth != icm._enable_iam_auth:
+                raise ValueError(
+                    f"connect() called with `enable_iam_auth={enable_iam_auth}`, "
+                    f"but previously used enable_iam_auth={icm._enable_iam_auth}`. "
+                    "If you require both for your use case, please use a new "
+                    "connector.Connector object."
+                )
         else:
-            enable_iam_auth = kwargs.pop("enable_iam_auth", self._enable_iam_auth)
             icm = InstanceConnectionManager(
                 instance_connection_string,
                 driver,
@@ -144,6 +150,23 @@ class Connector:
             icm.force_refresh()
             raise (e)
 
+    async def _close(self) -> None:
+        """Helper function to close InstanceConnectionManagers' tasks."""
+        await asyncio.gather(*[icm.close() for icm in self._instances.values()])
+
+    def __del__(self) -> None:
+        """Deconstructor to make sure InstanceConnectionManagers are closed
+        and tasks have finished to have a graceful exit.
+        """
+        logger.debug("Entering deconstructor")
+
+        deconstruct_future = asyncio.run_coroutine_threadsafe(
+            self._close(), loop=self._loop
+        )
+        # Will attempt to safely shut down tasks for 5s
+        deconstruct_future.result(timeout=5)
+        logger.debug("Finished deconstructing")
+
 
 def connect(instance_connection_string: str, driver: str, **kwargs: Any) -> Any:
     """Uses a Connector object with default settings and returns a database
